@@ -1,17 +1,21 @@
-#
-# This file is part of POE::Component::Client::MPD.
-# Copyright (c) 2007-2008 Jerome Quelin, all rights reserved.
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the same terms as Perl itself.
-#
-#
-
-package POE::Component::Client::MPD::Test;
-
+# 
+# This file is part of POE-Component-Client-MPD
+# 
+# This software is copyright (c) 2007 by Jerome Quelin.
+# 
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+# 
+use 5.010;
 use strict;
 use warnings;
 
+package POE::Component::Client::MPD::Test;
+our $VERSION = '0.9.4';
+
+
+# ABSTRACT: automate launching of fake mdp for testing purposes
+
 use FindBin qw{ $Bin };
 use POE;
 use POE::Component::Client::MPD;
@@ -38,7 +42,7 @@ sub import { # this will be run when pococm::Test will be use-d.
     $was_running = _stop_user_mpd_if_needed();
     $start_ok    = start_test_mpd();
 
-    END {
+    END { ## no critic
         stop_test_mpd() if $start_ok;
         return unless $was_running;   # no need to restart
         system 'mpd 2>/dev/null';     # restart user mpd
@@ -207,12 +211,18 @@ sub _onpriv_start {
 
 1;
 
-__END__
+
+
+
+=pod
 
 =head1 NAME
 
 POE::Component::Client::MPD::Test - automate launching of fake mdp for testing purposes
 
+=head1 VERSION
+
+version 0.9.4
 
 =head1 SYNOPSIS
 
@@ -220,7 +230,6 @@ POE::Component::Client::MPD::Test - automate launching of fake mdp for testing p
     [...]
     stop_fake_mpd();
 
-
 =head1 DESCRIPTION
 
 =head2 General usage
@@ -236,7 +245,6 @@ run the test mpd with its newly created configuration file.
 
 Everything described above is done automatically when the module is C<use>-d.
 
-
 Once the tests are run, the mpd server will be shut down, and the original
 one will be relaunched (if there was one).
 
@@ -244,7 +252,6 @@ Note that the test mpd will listen to C<localhost>, so you are on the safe
 side. Note also that the test suite comes with its own ogg files - and yes,
 we can redistribute them since it's only some random voice recordings :-)
 
-
 =head2 Advanced usage
 
 In case you want more control on the test mpd server, you can use the
@@ -267,28 +274,23 @@ located in t/mpd-test. The string PWD will be replaced by the real path -
 ie, where the tarball has been untarred. The string PORT will be replaced
 by $port if specified, 6600 otherwise (MPD default).
 
-=back
+=back 
 
 This might be useful when trying to test connections with mpd server.
 
-
-=head1 SEE ALSO
-
-For all related information (bug reporting, mailing-list, pointers to
-MPD and POE, etc.), refer to L<POE::Component::Client::MPD>'s pod,
-section C<SEE ALSO>
-
-
 =head1 AUTHOR
 
-Jerome Quelin, C<< <jquelin@cpan.org> >>
+  Jerome Quelin
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2007 by Jerome Quelin.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut 
 
 
-=head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2007-2008 Jerome Quelin, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=cut
+__END__
\ No newline at end of file
